# SerProg
A serial and secure programming tool for microcontroller.

### Reference project
- [SAME54BOOT]
  Bootloader for Microchip SAME54 series MCU (ARM Cortex-M4F)
- [NuM487BOOT]
  Bootloader for Nuvoton M480 series MCU (ARM Cortex-M4F)

### Bootloader Protocol

### Secure Boot

### Reference
asaloader (https://gitlab.com/MVMC-lab/hervor/asaloader)

Special thanks to LiYu87 for his early contributions to this project.
